pub fn or<B, C>(branches: impl IntoIterator<Item = B>) -> ClauseExpand description
An (or branches...) clause. Each branch is a group of clauses joined by
an implicit and.
pub fn or<B, C>(branches: impl IntoIterator<Item = B>) -> ClauseAn (or branches...) clause. Each branch is a group of clauses joined by
an implicit and.